==> walkers-fabric-1.18.2-4.5-sources.jar: tocraft/walkers/ability/impl/AngerAbility.java <==
package tocraft.walkers.ability.impl;

import it.unimi.dsi.fastutil.ints.Int2ObjectMap;
import net.minecraft.class_1308;
import net.minecraft.class_1657;
import net.minecraft.class_1792;
import net.minecraft.class_1802;
import net.minecraft.class_1937;
import net.minecraft.class_3218;
import net.minecraft.class_3222;
import net.minecraft.class_3414;
import net.minecraft.class_3417;
import net.minecraft.class_3419;
import net.minecraft.class_5354;
import tocraft.walkers.ability.ShapeAbility;
import tocraft.walkers.api.PlayerShape;
import tocraft.walkers.mixin.EntityTrackerAccessor;
import tocraft.walkers.mixin.ThreadedAnvilChunkStorageAccessor;

public class AngerAbility<T extends class_1308> extends ShapeAbility<T> {
    private final class_3414 notAggressiveSound;
    private final class_3414 aggressiveSound;
    private final class_1792 icon;

    public AngerAbility() {
        this(class_3417.field_14726, class_3417.field_15016);
    }

    public AngerAbility(class_3414 notAggressiveSound, class_3414 aggressionSound) {
        this(notAggressiveSound, aggressionSound, class_1802.field_8264);
    }

    public AngerAbility(class_3414 notAggressiveSound, class_3414 aggressionSound, class_1792 icon) {
        this.notAggressiveSound = notAggressiveSound;
        this.aggressiveSound = aggressionSound;
        this.icon = icon;
    }

    @Override
    public void onUse(class_1657 player, T oShape, class_1937 world) {
        if (oShape instanceof class_5354 shape) {
            if (shape.method_29511()) {
                shape.method_29922();
                world.method_8449(null, player, notAggressiveSound, class_3419.field_15248, 1.0F,
                        (world.field_9229.nextFloat() - world.field_9229.nextFloat()) * 0.2F + 1.0F);
            } else {
                shape.method_29509();
                world.method_8449(null, player, aggressiveSound, class_3419.field_15248, 1.0F,
                        (world.field_9229.nextFloat() - world.field_9229.nextFloat()) * 0.2F + 1.0F);

            }

            if (!world.method_8608()) {
                Int2ObjectMap<Object> trackers = ((ThreadedAnvilChunkStorageAccessor) ((class_3218) world)
                        .method_14178().field_17254).getEntityMap();
                Object tracking = trackers.get(player.method_5628());
                ((EntityTrackerAccessor) tracking).getSeenBy().forEach(
                        listener -> PlayerShape.sync((class_3222) player, listener.method_32311())
                );
            }
        }
    }

    @Override
    public class_1792 getIcon() {
        return icon;
    }
}

==> walkers-fabric-1.20.2-4.4.1-sources.jar: tocraft/walkers/ability/impl/AngerAbility.java <==
package tocraft.walkers.ability.impl;

import it.unimi.dsi.fastutil.ints.Int2ObjectMap;
import net.minecraft.class_1308;
import net.minecraft.class_1657;
import net.minecraft.class_1792;
import net.minecraft.class_1802;
import net.minecraft.class_1937;
import net.minecraft.class_3218;
import net.minecraft.class_3222;
import net.minecraft.class_3414;
import net.minecraft.class_3417;
import net.minecraft.class_3419;
import net.minecraft.class_5354;
import tocraft.walkers.ability.ShapeAbility;
import tocraft.walkers.api.PlayerShape;
import tocraft.walkers.mixin.EntityTrackerAccessor;
import tocraft.walkers.mixin.ThreadedAnvilChunkStorageAccessor;

public class AngerAbility<T extends class_1308> extends ShapeAbility<T> {
    private final class_3414 notAggressiveSound;
    private final class_3414 aggressiveSound;
    private final class_1792 icon;

    public AngerAbility() {
        this(class_3417.field_14726, class_3417.field_15016);
    }

    public AngerAbility(class_3414 notAggressiveSound, class_3414 aggressionSound) {
        this(notAggressiveSound, aggressionSound, class_1802.field_8264);
    }

    public AngerAbility(class_3414 notAggressiveSound, class_3414 aggressionSound, class_1792 icon) {
        this.notAggressiveSound = notAggressiveSound;
        this.aggressiveSound = aggressionSound;
        this.icon = icon;
    }

    @Override
    public void onUse(class_1657 player, T oShape, class_1937 world) {
        if (oShape instanceof class_5354 shape) {
            if (shape.method_29511()) {
                shape.method_29922();
                world.method_43129(null, player, notAggressiveSound, class_3419.field_15248, 1.0F,
                        (world.field_9229.method_43057() - world.field_9229.method_43057()) * 0.2F + 1.0F);
            } else {
                shape.method_29509();
                world.method_43129(null, player, aggressiveSound, class_3419.field_15248, 1.0F,
                        (world.field_9229.method_43057() - world.field_9229.method_43057()) * 0.2F + 1.0F);

            }

            if (!world.method_8608()) {
                Int2ObjectMap<Object> trackers = ((ThreadedAnvilChunkStorageAccessor) ((class_3218) world)
                        .method_14178().field_17254).getEntityMap();
                Object tracking = trackers.get(player.method_5628());
                ((EntityTrackerAccessor) tracking).getSeenBy().forEach(
                        listener -> PlayerShape.sync((class_3222) player, listener.method_32311())
                );
            }
        }
    }

    @Override
    public class_1792 getIcon() {
        return icon;
    }
}
